@@ -1,10 +1,19 @@
 import argparse
+import inspect
 import io
+from importlib import metadata
+from sys import stderr
 from typing import TextIO
 
 import markovify
 
 
+try:
+    VERSION = metadata.version(inspect.getmodulename(__file__))
+except:
+    VERSION = 'unknown'
+
+
 class MarkovChatter():
 
     def __init__(self, text: str, state_size=2, word_divider=' ', new_line=False) -> None:
@@ -18,7 +27,12 @@ class MarkovChatter():
 
     def make_sentence(self) -> str:
 
-        return self._word_divider.join(self._model.make_sentence().split())
+        sentence = self._model.make_sentence()
+        if sentence is None:
+            print(f'{__class__.__name__}.{inspect.currentframe().f_code.co_name}:',
+                  'failed to generate sentence', file=stderr)
+            sentence = ''
+        return self._word_divider.join(sentence.split())
 
 
 def chatter_from_args(args: argparse.Namespace) -> MarkovChatter:
@@ -54,6 +68,11 @@ def _server(args: argparse.Namespace) -> None:
     app.run(args.host, args.port)
 
 
+def _version(args: argparse.Namespace) -> None:
+
+    print(VERSION)
+
+
 def main() -> None:
 
     parser = argparse.ArgumentParser()
@@ -79,6 +98,9 @@ def main() -> None:
     _parser.add_argument('-p', '--port', type=int, default=8080,
                          help='listen port number [%(default)d]')
 
+    _parser = subparsers.add_parser('version', help='show version and exit')
+    _parser.set_defaults(func=_version)
+
     args = parser.parse_args()
     if not hasattr(args, 'func'):
         parser.print_help()
